@@ -1,6 +1,7 @@
 # -*- encoding: utf-8 -*-
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -83,7 +84,7 @@ class Filter(callbacks.Plugin):
                        'scramble', 'morse', 'reverse', 'colorize', 'squish',
                        'supa1337', 'stripcolor', 'aol', 'rainbow', 'spellit',
                        'hebrew', 'undup', 'uwu', 'gnu', 'shrink', 'uniud', 'capwords',
-                       'caps', 'vowelrot']
+                       'caps', 'vowelrot', 'stripformatting']
     @internationalizeDocstring
     def outfilter(self, irc, msg, args, channel, command):
         """[<channel>] [<command>]
@@ -420,6 +421,13 @@ class Filter(callbacks.Plugin):
         irc.reply(''.join(L) + '\x03')
     rainbow = wrap(rainbow, ['text'])
 
+    @wrap(['text'])
+    def stripformatting(self, irc, msg, args, text):
+        """<text>
+
+        Strips bold, underline, and colors from <text>."""
+        irc.reply(ircutils.stripFormatting(text))
+
     @internationalizeDocstring
     def stripcolor(self, irc, msg, args, text):
         """<text>
