@@ -1,5 +1,6 @@
 ###
 # Copyright (c) 2004-2005, Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -49,13 +50,6 @@ class Format(callbacks.Plugin):
         irc.reply(ircutils.bold(text))
     bold = wrap(bold, ['text'])
 
-    @wrap(['text'])
-    def stripformatting(self, irc, msg, args, text):
-        """<text>
-
-        Strips bold, underline, and colors from <text>."""
-        irc.reply(ircutils.stripFormatting(text))
-
     @internationalizeDocstring
     def reverse(self, irc, msg, args, text):
         """<text>
