@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2009, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -338,7 +339,7 @@ class Misc(callbacks.Plugin):
         Returns the version of the current bot.
         """
         try:
-            newestUrl = 'https://api.github.com/repos/ProgVal/Limnoria/' + \
+            newestUrl = 'https://api.github.com/repos/progval/Limnoria/' + \
                     'commits/%s'
             versions = {}
             for branch in ('master', 'testing'):
@@ -369,7 +370,7 @@ class Misc(callbacks.Plugin):
 
         Returns a URL saying where to get Limnoria.
         """
-        irc.reply(_('My source is at https://github.com/ProgVal/Limnoria'))
+        irc.reply(_('My source is at https://github.com/progval/Limnoria'))
     source = wrap(source)
 
     @internationalizeDocstring
