@@ -1,5 +1,5 @@
 ###
-# Copyright (c) 2011, Valentin Lorentz
+# Copyright (c) 2011-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -197,8 +197,8 @@ class GithubRepository(GitRepository):
 
 
 repositories = utils.InsensitivePreservingDict({
-               'ProgVal':          GithubRepository(
-                                                   'ProgVal',
+               'progval':          GithubRepository(
+                                                   'progval',
                                                    'Supybot-plugins'
                                                    ),
                'quantumlemur':     GithubRepository(
@@ -348,14 +348,14 @@ class PluginDownloader(callbacks.Plugin):
         < Mikaela> @load PluginDownloader
         < Limnoria> Ok.
         < Mikaela> @plugindownloader repolist
-        < Limnoria> Antibody, jlu5, Hoaas, Iota, ProgVal, SpiderDave, boombot, code4lib, code4lib-edsu, code4lib-snapshot, doorbot, frumious, jonimoose, mailed-notifier, mtughan-weather, nanotube-bitcoin, nyuszika7h, nyuszika7h-old, pingdom, quantumlemur, resistivecorpse, scrum, skgsergio, stepnem
-        < Mikaela> @plugindownloader repolist ProgVal
+        < Limnoria> Antibody, jlu5, Hoaas, Iota, progval, SpiderDave, boombot, code4lib, code4lib-edsu, code4lib-snapshot, doorbot, frumious, jonimoose, mailed-notifier, mtughan-weather, nanotube-bitcoin, nyuszika7h, nyuszika7h-old, pingdom, quantumlemur, resistivecorpse, scrum, skgsergio, stepnem
+        < Mikaela> @plugindownloader repolist progval
         < Limnoria> AttackProtector, AutoTrans, Biography, Brainfuck, ChannelStatus, Cleverbot, Coffee, Coinpan, Debian, ERepublik, Eureka, Fortune, GUI, GitHub, Glob2Chan, GoodFrench, I18nPlaceholder, IMDb, IgnoreNonVoice, Iwant, Kickme, LimnoriaChan, LinkRelay, ListEmpty, Listener, Markovgen, MegaHAL, MilleBornes, NoLatin1, NoisyKarma, OEIS, PPP, PingTime, Pinglist, RateLimit, Rbls, Redmine, Scheme, Seeks, (1 more message)
         < Mikaela> more
         < Limnoria> SilencePlugin, StdoutCapture, Sudo, SupyML, SupySandbox, TWSS, Trigger, Trivia, Twitter, TwitterStream, Untiny, Variables, WebDoc, WebLogs, WebStats, Website, WikiTrans, Wikipedia, WunderWeather
-        < Mikaela> @plugindownloader info ProgVal Wikipedia
+        < Mikaela> @plugindownloader info progval Wikipedia
         < Limnoria> Grabs data from Wikipedia.
-        < Mikaela> @plugindownloader install ProgVal Wikipedia
+        < Mikaela> @plugindownloader install progval Wikipedia
         < Limnoria> Ok.
         < Mikaela> @load Wikipedia
         < Limnoria> Ok.
