@@ -1,7 +1,7 @@
 ###
 # Copyright (c) 2002-2004, Jeremiah Fincher
 # Copyright (c) 2008-2010, James McCoy
-# Copyright (c) 2014, Valentin Lorentz
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -197,7 +197,7 @@ class RSS(callbacks.Plugin):
     ^^^^^^^^^^^
 
     1. Add a feed using
-       ``@rss add limnoria https://github.com/ProgVal/Limnoria/tags.atom``.
+       ``@rss add limnoria https://github.com/progval/Limnoria/tags.atom``.
 
        * This is RSS feed of Limnoria's stable releases.
        * You can now check the latest news from the feed with ``@limnoria``.
@@ -287,7 +287,9 @@ class RSS(callbacks.Plugin):
 
     def register_feed(self, name, url, initial,
             plugin_is_loading, announced=None):
-        self.feed_names[name] = url
+        if name != url:
+            # If name == url, then it's an anonymous feed
+            self.feed_names[name] = url
         self.feeds[url] = Feed(name, url, initial,
                 plugin_is_loading, announced)
 
@@ -386,7 +388,7 @@ class RSS(callbacks.Plugin):
     def update_feeds(self):
         announced_feeds = {}
         for irc in world.ircs:
-            for channel in irc.state.channels:
+            for channel in list(irc.state.channels):
                 channel_feed_names = self.registryValue(
                     'announce', channel, irc.network)
                 for name in channel_feed_names:
@@ -421,7 +423,7 @@ class RSS(callbacks.Plugin):
         order = self.registryValue('sortFeedItems')
         new_entries = sort_feed_items(new_entries, 'newestFirst')
         for irc in world.ircs:
-            for channel in irc.state.channels:
+            for channel in list(irc.state.channels):
                 # Old bots have it set in plugins.RSS.announce.#channel,
                 # new bots set it in plugins.RSS.announce.:network.#channel,
                 # so we want to read from both.
@@ -623,7 +625,7 @@ class RSS(callbacks.Plugin):
 
             channels = []
             for ircnet in world.ircs:
-                for channel in ircnet.state.channels:
+                for channel in list(ircnet.state.channels):
                     if feed in plugin.registryValue('announce', channel, ircnet.network):
                         channels.append(ircnet.network + channel)
 
