@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2015, Michael Daniel Telatynski <postmaster@webdevguru.co.uk>
 # Copyright (c) 2015-2020, James Lu <james@overdrivenetworks.com>
+# Copyright (c) 2020-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -45,7 +46,7 @@ __contributors__ = {supybot.authors.jlu:
                    }
 __maintainer__ = supybot.authors.limnoria_core
 
-__url__ = 'https://github.com/ProgVal/Limnoria/tree/master/plugins/SedRegex'
+__url__ = 'https://github.com/progval/Limnoria/tree/master/plugins/SedRegex'
 
 from . import config
 from . import plugin
