@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2003-2005, Jeremiah Fincher
 # Copyright (c) 2009, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -76,6 +77,11 @@ def group(seq, groupSize, noneFill=True):
 
 class StringTestCase(PluginTestCase):
     plugins = ('String', 'Format', 'Status')
+
+    config = {
+        'plugins.String.re.timeout': 2.  # flaky on busy CIs otherwise
+    }
+
     def testLen(self):
         self.assertResponse('len foo', '3')
         self.assertHelp('len')
