@@ -1,5 +1,6 @@
 ###
 # Copyright (c) 2005, Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -175,5 +176,11 @@ class WebTestCase(ChannelPluginTestCase):
         finally:
             conf.supybot.plugins.Web.nonSnarfingRegexp.set('')
 
+    def testFetchIri(self):
+        self.assertRegexp('fetch http://café.example.org/',
+            'Error: .*is not a valid')
+        self.assertRegexp('fetch http://example.org/café',
+            'Error: .*is not a valid')
+
 
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
