@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -77,7 +78,7 @@ class authors(object): # This is basically a bag.
     bear = Author('Mike Taylor', 'bear', 'bear@code-bear.com')
     grantbow = Author('Grant Bowman', 'Grantbow', 'grantbow@grantbow.com')
     stepnem = Author('Štěpán Němec', 'stepnem', 'stepnem@gmail.com')
-    progval = Author('Valentin Lorentz', 'ProgVal', 'progval@gmail.com')
+    progval = Author('Valentin Lorentz', 'progval', 'progval@gmail.com')
     jlu = Author('James Lu', email='james@overdrivenetworks.com')
     unknown = Author('Unknown author', email='unknown@email.invalid')
 
