@@ -2,6 +2,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2014, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -79,7 +80,9 @@ def _addressed(irc, msg, prefixChars=None, nicks=None,
                 payload = payload[len(prefixString):].lstrip()
         return payload
 
-    assert msg.command in ('PRIVMSG', 'TAGMSG')
+    if msg.command == 'NOTICE':
+        return ''
+    assert msg.command in ('PRIVMSG', 'TAGMSG'), msg.command
     target = msg.channel or msg.args[0]
     if not payload:
         payload = msg.args[1]
