@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2009-2010,2015, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -666,12 +667,25 @@ def getGlob(irc, msg, args, state):
         glob = '*%s*' % glob
     state.args.append(glob)
 
+def _checkUrl(state, url):
+    try:
+        url.encode('ascii')
+    except UnicodeEncodeError:
+        state.errorInvalid(_('url'), url)
+
 def getUrl(irc, msg, args, state):
     if utils.web.urlRe.match(args[0]):
+        _checkUrl(state, args[0])
         state.args.append(args.pop(0))
     else:
         state.errorInvalid(_('url'), args[0])
 
+def getIri(irc, msg, args, state):
+    if utils.web.urlRe.match(args[0]):
+        state.args.append(args.pop(0))
+    else:
+        state.errorInvalid(_('IRI'), args[0])
+
 def getEmail(irc, msg, args, state):
     if utils.net.emailRe.match(args[0]):
         state.args.append(args.pop(0))
@@ -679,6 +693,16 @@ def getEmail(irc, msg, args, state):
         state.errorInvalid(_('email'), args[0])
 
 def getHttpUrl(irc, msg, args, state):
+    if utils.web.httpUrlRe.match(args[0]):
+        _checkUrl(state, args[0])
+        state.args.append(args.pop(0))
+    elif utils.web.httpUrlRe.match('http://' + args[0]):
+        _checkUrl(state, 'http://' + args[0])
+        state.args.append('http://' + args.pop(0))
+    else:
+        state.errorInvalid(_('http url'), args[0])
+
+def getHttpIri(irc, msg, args, state):
     if utils.web.httpUrlRe.match(args[0]):
         state.args.append(args.pop(0))
     elif utils.web.httpUrlRe.match('http://' + args[0]):
@@ -785,6 +809,7 @@ wrappers = ircutils.IrcDict({
     'haveVoice+': getHaveVoicePlus,
     'hostmask': getHostmask,
     'httpUrl': getHttpUrl,
+    'httpIri': getHttpIri,
     'id': getId,
     'inChannel': inChannel,
     'index': getIndex,
@@ -818,6 +843,7 @@ wrappers = ircutils.IrcDict({
     'text': getText,
     'to': getTo,
     'url': getUrl,
+    'iri': getIri,
     'user': getUser,
     'validChannel': validChannel,
     'voice': getVoice,
