@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2008-2009,2011, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -430,8 +431,9 @@ def registerNetwork(name, password='', ssl=True, sasl_username='',
         The public key must be registered with NickServ for SASL
         ECDSA-NIST256P-CHALLENGE to work.""") % name, private=False))
     registerGlobalValue(sasl, 'mechanisms', SpaceSeparatedListOfSaslMechanisms(
-        ['ecdsa-nist256p-challenge', 'external', 'plain'], _("""Determines
-        what SASL mechanisms will be tried and in which order.""")))
+        ['scram-sha-256', 'external', 'ecdsa-nist256p-challenge', 'plain'],
+        _("""Determines what SASL mechanisms will be tried and in which order.
+        """)))
     registerGlobalValue(sasl, 'required', registry.Boolean(False,
         _("""Determines whether the bot will abort the connection if the
         none of the enabled SASL mechanism succeeded.""")))
@@ -736,7 +738,7 @@ registerChannelValue(supybot.replies, 'requiresPrivacy',
 registerChannelValue(supybot.replies, 'possibleBug',
     registry.NormalizedString(_("""This may be a bug.  If you think it is,
     please file a bug report at
-    <https://github.com/ProgVal/Limnoria/issues>."""),
+    <https://github.com/progval/Limnoria/issues>."""),
     _("""Determines what message the bot sends when it thinks you've
     encountered a bug that the developers don't know about.""")))
 
