@@ -1,6 +1,7 @@
 ##
 # Copyright (c) 2002-2004, Jeremiah Fincher
 # Copyright (c) 2010, 2013, James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -211,7 +212,17 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
             lines = self.inbuffer.split(b'\n')
             self.inbuffer = lines.pop()
             for line in lines:
-                line = decode_raw_line(line)
+                if self.irc is not None \
+                        and 'UTF8ONLY' in self.irc.state.supported:
+                    # No need for the fancy charset-guessing used in
+                    # decode_raw_line.
+                    try:
+                        line = line.decode('utf8')
+                    except UnicodeError:
+                        drivers.log.exception('Could not decode line %r', line)
+                        continue
+                else:
+                    line = decode_raw_line(line)
 
                 msg = drivers.parseMsg(line)
                 if msg is not None and self.irc is not None:
