@@ -1,5 +1,6 @@
 ###
 # Copyright (c) 2002-2005 Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -1991,8 +1992,8 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             self.endCapabilityNegociation(msg)
 
     def do904(self, msg):
-        log.warning('%s: SASL authentication failed (mechanism: %s)',
-                self.network, self.sasl_current_mechanism)
+        log.warning('%s: SASL authentication failed (mechanism: %s): %s',
+                self.network, self.sasl_current_mechanism, msg.args[-1])
         self.tryNextSaslMechanism(msg)
 
     def do905(self, msg):
@@ -2049,7 +2050,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             or (self.driver.ssl and self.driver.anyCertValidationEnabled())
 
         parsed_policy = ircutils.parseStsPolicy(
-            log, policy, parseDuration=secure_connection)
+            log, policy, secure_connection=secure_connection)
         if parsed_policy is None:
             # There was an error (and it was logged). Ignore it and proceed
             # with the connection.
@@ -2064,9 +2065,14 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             # For future-proofing (because we don't want to write an invalid
             # value), we write the raw policy received from the server instead
             # of the parsed one.
-            log.debug('Storing STS policy: %s', policy)
+            log.debug('Storing STS policy for %s (TLS port %s): %s',
+                self.driver.currentServer.hostname,
+                self.driver.currentServer.port,
+                policy)
             ircdb.networks.getNetwork(self.network).addStsPolicy(
-                self.driver.currentServer.hostname, policy)
+                self.driver.currentServer.hostname,
+                self.driver.currentServer.port,
+                policy)
         else:
             hostname = self.driver.currentServer.hostname
             attempt = self.driver.currentServer.attempt
@@ -2132,7 +2138,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             # sets are unordered, and their "order" is nondeterministic.
             # This is needed for the tests.
             if new_caps:
-                self._requestCaps(new_caps)
+                self.requestCapabilities(new_caps)
             else:
                 self.endCapabilityNegociation(msg)
         else:
@@ -2174,9 +2180,16 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 self.REQUEST_CAPABILITIES -
                 self.state.capabilities_ack)
         if common_supported_unrequested_capabilities:
-            self._requestCaps(common_supported_unrequested_capabilities)
+            self.requestCapabilities(common_supported_unrequested_capabilities)
 
-    def _requestCaps(self, caps):
+    def requestCapabilities(self, caps):
+        """Takes an iterable of IRCv3 capabilities, and requests them to the
+        server using CAP REQ.
+
+        This is mostly just used during connection registration or when the
+        server sends CAP NEW; but plugins may use it as well to request custom
+        capabilities. They should make sure these capabilities cannot
+        negatively impact other plugins, though."""
         caps = list(sorted(caps))
         cap_lines = []
         if 'echo-message' in caps \
