@@ -1,6 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2009,2011,2015 James McCoy
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -1072,11 +1073,15 @@ def parseCapabilityKeyValue(s):
     return d
 
 
-def parseStsPolicy(logger, policy, parseDuration):
+def parseStsPolicy(logger, policy, secure_connection):
     parsed_policy = parseCapabilityKeyValue(policy)
 
     for key in ('port', 'duration'):
-        if key == 'duration' and not parseDuration:
+        if key == 'duration' and not secure_connection:
+            if key in parsed_policy:
+                del parsed_policy[key]
+            continue
+        elif key == 'port' and secure_connection:
             if key in parsed_policy:
                 del parsed_policy[key]
             continue
