@@ -1,5 +1,6 @@
 ##
 # Copyright (c) 2002-2005, Jeremiah Fincher
+# Copyright (c) 2010-2021, The Limnoria Contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -758,16 +759,27 @@ class StsTestCase(SupyTestCase):
         self.irc.driver.ssl = True
         self.irc.driver.currentServer = drivers.Server('irc.test', 6697, None, False)
         self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
-            args=('*', 'LS', 'sts=duration=42,port=6697')))
+            args=('*', 'LS', 'sts=duration=42,port=12345')))
 
         self.assertEqual(ircdb.networks.getNetwork('test').stsPolicies, {
-            'irc.test': 'duration=42,port=6697'})
+            'irc.test': (6697, 'duration=42,port=12345')})
+        self.irc.driver.reconnect.assert_not_called()
+
+    def testStsInSecureConnectionNoPort(self):
+        self.irc.driver.anyCertValidationEnabled.return_value = True
+        self.irc.driver.ssl = True
+        self.irc.driver.currentServer = drivers.Server('irc.test', 6697, None, False)
+        self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
+            args=('*', 'LS', 'sts=duration=42')))
+
+        self.assertEqual(ircdb.networks.getNetwork('test').stsPolicies, {
+            'irc.test': (6697, 'duration=42')})
         self.irc.driver.reconnect.assert_not_called()
 
     def testStsInInsecureTlsConnection(self):
         self.irc.driver.anyCertValidationEnabled.return_value = False
         self.irc.driver.ssl = True
-        self.irc.driver.currentServer = drivers.Server('irc.test', 6697, None, False)
+        self.irc.driver.currentServer = drivers.Server('irc.test', 6667, None, False)
         self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
             args=('*', 'LS', 'sts=duration=42,port=6697')))
 
@@ -1361,10 +1373,16 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
             conf.supybot.networks.test.sasl.username.setValue('')
             conf.supybot.networks.test.sasl.password.setValue('')
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.assertEqual(self.irc.sasl_next_mechanisms, ['plain'])
+        self.irc.sasl_next_mechanisms = ['scram-sha-256', 'plain']
 
         self.startCapNegociation()
 
+        m = self.irc.takeMsg()
+        self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
+            args=('SCRAM-SHA-256',)))
+        self.irc.feedMsg(ircmsgs.IrcMsg(command='904',
+            args=('mechanism not available',)))
+
         m = self.irc.takeMsg()
         self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
             args=('PLAIN',)))
@@ -1391,15 +1409,13 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
             conf.supybot.networks.test.sasl.password.setValue('')
             conf.supybot.networks.test.certfile.setValue('')
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.assertEqual(self.irc.sasl_next_mechanisms,
-                ['external', 'plain'])
+        self.irc.sasl_next_mechanisms = ['external', 'plain']
 
         self.startCapNegociation()
 
         m = self.irc.takeMsg()
         self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
             args=('EXTERNAL',)))
-
         self.irc.feedMsg(ircmsgs.IrcMsg(command='904',
             args=('mechanism not available',)))
 
@@ -1429,8 +1445,7 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
             conf.supybot.networks.test.sasl.password.setValue('')
             conf.supybot.networks.test.certfile.setValue('')
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.assertEqual(self.irc.sasl_next_mechanisms,
-                ['external', 'plain'])
+        self.irc.sasl_next_mechanisms = ['external', 'plain']
 
         self.startCapNegociation(caps='sasl=foo,plain,bar')
 
@@ -1458,7 +1473,7 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
             conf.supybot.networks.test.sasl.username.setValue('')
             conf.supybot.networks.test.sasl.password.setValue('')
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.assertEqual(self.irc.sasl_next_mechanisms, ['plain'])
+        self.irc.sasl_next_mechanisms = ['plain']
 
         self.startCapNegociation(caps='')
 
